@@ -1,5 +1,4 @@
-/*
- *
+/* *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2006-2007  Nokia Corporation
@@ -30,11 +29,20 @@ void hcid_dbus_exit(void);
 int hcid_dbus_init(void);
 void hcid_dbus_unregister(void);
 
-void dbus_message_iter_append_dict_entry(DBusMessageIter *dict,
-					const char *key, int type, void *val);
+void dict_append_entry(DBusMessageIter *dict,
+			const char *key, int type, void *val);
 
-dbus_bool_t dbus_connection_emit_property_changed(DBusConnection *conn,
-						const char *path,
-						const char *interface,
-						const char *name,
-						int type, void *value);
+void dict_append_array(DBusMessageIter *dict, const char *key, int type,
+			void *val, int n_elements);
+
+dbus_bool_t emit_property_changed(DBusConnection *conn,
+					const char *path,
+					const char *interface,
+					const char *name,
+					int type, void *value);
+
+dbus_bool_t emit_array_property_changed(DBusConnection *conn,
+					const char *path,
+					const char *interface,
+					const char *name,
+					int type, void *value);
